==> kuroo-0.90.5_p20180410.tar.xz: kuroo-0.90.5_p20180410/src/history/mergetab.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Karye   *
 *   karye@users.sourceforge.net   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef MERGETAB_H
#define MERGETAB_H

#include "ui_mergebase.h"

/**
 * @class MergeTab
 * @short Tabpage for emerge log browser, emerge history and portage directories sizes.
 */
class MergeTab : public QWidget, public Ui::MergeBase
{
Q_OBJECT
public:
    MergeTab( QWidget *parent = 0 );
    ~MergeTab();

private slots:
	void 		slotInit();
	
	void		slotWhatsThis();
	
	void		slotReload();
	void		slotLoadConfFiles();
	void		slotClearFilter();
	void		slotButtonView();
	void		slotButtonMerge();
	void 		slotViewFile();
	void		slotMergeFile();
	
signals:
	void		signalMergeChanged();
	
};

#endif

==> kuroo-1.2.4.tar.xz: kuroo-1.2.4/src/history/mergetab.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Karye   *
 *   karye@users.sourceforge.net   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef MERGETAB_H
#define MERGETAB_H

#include <qobjectdefs.h>   // for Q_OBJECT, signals, slots
#include <qstring.h>       // for QString
#include <qwidget.h>       // for QWidget

#include "ui_mergebase.h"  // for MergeBase


/**
 * @class MergeTab
 * @short Tabpage for emerge log browser, emerge history and portage directories sizes.
 */
class MergeTab : public QWidget, public Ui::MergeBase
{
Q_OBJECT
public:
	MergeTab( QWidget *parent = nullptr );
	~MergeTab();

private Q_SLOTS:
	void 		slotInit();
	
	void		slotWhatsThis();
	
	static void		slotReload();
	void		slotLoadConfFiles();
	void		slotClearFilter();
	void		slotButtonView();
	void		slotButtonMerge();
	void 		slotViewFile();
	void		slotMergeFile();
	
Q_SIGNALS:
	void		signalMergeChanged();
};

#endif
